var auth = {

	elements: {

		login: {

			form: '#authentication-login-form',

			email_address: '#login-email-address',

			password: '#login-password',

		},

		edit: {

			form: '#authentication-edit-form',

			first_name: '#authentication-edit-firstname',

			last_name: '#authentication-edit-lastname',

			company_name: '#authentication-edit-companyname',

			trading_name: '#authentication-edit-tradingname',

			postcode: '#authentication-edit-postcode',

			abn: '#authentication-edit-abn',

		},

		register: {

			form: '#authentication-register-form',

			first_name: '#register-firstname',

			last_name: '#register-lastname',

			company_name: '#register-companyname',

			trading_name: '#register-tradingname',

			postcode: '#register-postcode',

			abn: '#register-abn',

			email_address: '#register-emailaddress',

			password: '#register-password',

			confirm_password: '#register-confirmpassword',

		},

		reset: {

			one: {

				form: '#authentication-reset-one-form',

				email_address: '#reset-one-emailaddress',

			},

			two: {

				form: '#authentication-reset-two-form',

				email_address: '#reset-two-emailaddress',

				abn: '#reset-two-code',

				password: '#reset-two-password',

				confirm_password: '#reset-two-confirmpassword',

			}

		},

		account: {

			overview: {

				display_name: '#account-overview-displayname',

				device: '#account-overview-device',

				lastlogin: '#account-overview-lastlogin'

			},

			logout: {

				disabled: '.account-logout-disabled',

				ready: '.account-logout-ready',

				title: '#account-logout-title'

			},

			profile: {

				form: '#account-profile-form',

				id: '#profile-id',

				first_name: '#profile-firstname',

				last_name: '#profile-lastname',

				company_name: '#profile-companyname',

				trading_name: '#profile-tradingname',

				postcode: '#profile-postcode',

				abn: '#profile-abn'

			}

		}

	},

	init: function() {

		auth.init_overview();

		auth.init_logout();

	},

	init_overview: function() {

		var content = helper.content();

		// Overview

		$( auth.elements.account.overview.display_name ).text( content['user']['user_firstname'] + ' ' + content['user']['user_lastname'] );

		$( auth.elements.account.overview.lastlogin ).text( content['user']['user_lastlogin'] );

		$( auth.elements.account.overview.device ).text( content['user']['device'] );

		// Profile

		$( auth.elements.account.profile.id ).val( content['user']['user_id'] );

		$( auth.elements.account.profile.first_name ).val( content['user']['user_firstname'] );

		$( auth.elements.account.profile.last_name ).val( content['user']['user_lastname'] );

		$( auth.elements.account.profile.company_name ).val( content['user']['user_companyname'] );

		$( auth.elements.account.profile.trading_name ).val( content['user']['user_tradingname'] );

		$( auth.elements.account.profile.abn ).val( content['user']['user_abn'] );

		$( auth.elements.account.profile.postcode ).val( content['user']['user_postcode'] );

	},

	init_logout: function() {

		var update = Lungo.Cache.get( 'update' )['data'];

		if ( update.length == 0 ) {

			$( auth.elements.account.logout.ready ).removeClass( 'hidden' );

			$( auth.elements.account.logout.disabled ).addClass( 'hidden' );

			$( auth.elements.account.logout.title ).text( 'Logout' );

		} else {

			$( auth.elements.account.logout.ready ).addClass( 'hidden' );

			$( auth.elements.account.logout.disabled ).removeClass( 'hidden' );

			$( auth.elements.account.logout.title ).text( 'Pending Changes' );

		}

	},

	login: function() {

		var request = helper.validate_form( $( auth.elements.login.form ) );

		if ( request != false ) {

			Lungo.Notification.show();

			request['encrypted'] = false;

			request['local_datetime'] = helper.get_date_format();

			var env = Lungo.Core.environment();

			request['device'] = env['os'] == null ? 'Desktop' : env['os'].name;

			helper.ajax( variables.request_login, request, function( response_json ) {

				var response_obj = $.parseJSON( atob( response_json ) );

				switch( response_obj.response ) {

					case '-1':

							helper.error();

						break;

					case '0':

							sync.save( response_obj );

							Lungo.Router.article( 'home', 'home-menu' );

							Lungo.Notification.success( 'Login successful', '', 'ok', 2, function() {

								Lungo.Notification.hide();

							} );

						break;

					case '1':

							Lungo.Notification.confirm( {

								icon: 'question-sign',

								title: 'We could not find an account with that email address',

								description: 'Would you like to create an account?',

								accept: {

									label: 'Yes',

									callback: function() {

										Lungo.Router.article( 'authentication', 'authentication-register' );

									}

								},

								cancel: {

									label: 'Try again',

									callback: function() {

										Lungo.Notification.hide();

									}
									
								}

							} );

						break;

					case '2':

							Lungo.Notification.error( 'Incorrect password', 'Please try again', 'warning-sign' );

						break;

					default:

						helper.error();

				}

			}, function() {

				helper.error();

			} );

		}

	},

	save: function() {

		var request = helper.validate_form( $( auth.elements.account.profile.form ) );

		if ( request != false ) {

			var method = 'update';

			var content = helper.content();

			var data = {

				user_firstname: request['user_firstname'],

				user_lastname: request['user_lastname'],

				user_companyname: request['user_companyname'],

				user_tradingname: request['user_tradingname'],

				user_abn: request['user_abn'],

				user_postcode: request['user_postcode']

			};

			$.extend( content['user'], data );

			helper.content( content );

			update.update( 'user_app', method, request['user_id'], data );

			auth.init_overview();

			Lungo.Router.back();

		}

	},

	register: function() {

		var request = helper.validate_form( $( auth.elements.register.form ) );

		if ( request != false ) {

			Lungo.Notification.confirm( {

				icon: 'warning-sign',

				title: 'Notice',

				description:	'<strong class="text bold">Privacy Note</strong>' +
								'This information is not for any other purpose other than ensuring legitimate businesses are accessing this service. ' + 
								'<b>No information will be shared with third parties</b> and your information will only be used in-line with the consent form.' +

								'<strong class="text bold">Disclaimer</strong>' + 
								'Any representation, statement, opinion or advice expressed or implied in this mobile Application is made ' + 
								'in good faith but on the basis that the NCSTT and its partners are not liable (whether by reason of negligence, ' + 
								'lack of care or otherwise) to any person for any damage or loss whatsoever which has occurred or may occur in ' + 
								'relation to that person taking or not taking (as the case may be) action in respect of any representation, statement ' + 
								'or advice referred to in this mobile Application.<br /><br />' + 

								'<strong class="text bold">Client Consent Form</strong>' + 
								'<b>Consent to Provision of Client Contact Details to the Department of Industry</b> ' + 
								'The services provided by the National Centre for Studies in Travel and Tourism Pty Ltd. (NCSTT) are funded by ' + 
								'the Australian Government through the Department of Industry<br /><br />' + 

								'As part of the Australian Government\'s efforts to evaluate the effectiveness of the services provided by the NCSTT, ' + 
								'and to seek areas for improvement in their services, the Australian Government has requested the contact information of clients who access the funded services.<br /><br />' + 

								'Your contact information will only be used to provide you with evaluation surveys about the services provided to you by the NCSTT.<br /><br />' + 

								'The Department of Industry will keep your contact details protected, ' + 
								'in line with the Information Privacy Principles contained Ready, Set, Go! Mobile Application Content Outline (DRAFT) 5 in the Privacy Act 1988, ' + 
								'and we will only use your details for the purpose of conducting surveys in regard to the Small Business Advisory Services program. ' + 
								'Such a survey may be carried out by a reputable market research organisation which would be contractually bound to the Information Privacy ' + 
								'Principles contained in the Privacy Act 1988 as if they were part of the Department. The results of any survey will be aggregate data and ' + 
								'will not be capable of identifying you or your organisation individually.<br /><br />' + 

								'Please note that participation in the evaluation of the services provided by the NCSTT is not mandatory and will not affect your eligibility ' + 
								'for services under the Small Business Advisory Services program. You may withdraw your consent to participate in the evaluation of the Small Business ' + 
								'Advisory Services program at any time by contacting the NCSTT.<br /><br />' + 

								'I consent to the provision of my contact details to the Department of Industry ' + 
								'for the purpose of including me in any survey in order to evaluate the Small Business Advisory Services program.',

				accept: {

					label: 'Confirm',

					callback: function() {

						setTimeout( function() {

							Lungo.Notification.show();

							request['encrypted'] = false;

							request['local_datetime'] = helper.get_date_format();

							var env = Lungo.Core.environment();

							request['device'] = env['os'] == null ? 'Desktop' : env['os'].name;

							helper.ajax( variables.request_register, request, function( response_json ) {

								var response_obj = $.parseJSON( atob( response_json ) );

								switch( response_obj.response ) {

									case '-1':

											helper.error();

										break;

									case '0':

											sync.save( response_obj );

											Lungo.Router.article( 'home', 'home-menu' );

											Lungo.Notification.success( 'Registration successful', '', 'ok', 2, function() {

												Lungo.Notification.hide();

											} );

										break;

									case '3':

											Lungo.Notification.confirm( {

												icon: 'question-sign',

												title: 'An account with that email address already exists',

												description: 'Would you like to reset your password?',

												accept: {

													label: 'Reset password',

													callback: function() {

														Lungo.Router.article( 'user', 'register--form' );

													}

												},

												cancel: {

													label: 'Login',

													callback: function() {

														Lungo.Router.article( 'user', 'login--form' );

													}

												}

											} );

										break;

									default:

										helper.error();

								}


							}, function() {

								helper.error();

							} );

						}, 500 );

					}

				},

				cancel: {

					label: 'Do not proceed',

					callback: function() {}
					
				}

			} );

		}

	},

	logout: function() {

		if ( in_device ) {

			variables.fe['content'].remove();

			variables.fe['update'].remove();

		}

		Lungo.Cache.remove( 'content' );

		Lungo.Cache.remove( 'update' );

		if ( in_device ) {

			location.reload();

			// navigator.app.exitApp();

		} else {

			location.reload();

		}

	},

	verify: function() {

		var request = helper.validate_form( $( auth.elements.reset.one.form ) );

		if ( request != false ) {

			Lungo.Notification.show();

			helper.ajax( variables.request_verify, request, function( response_json ) {

				var response_obj = $.parseJSON( atob( response_json ) );

				switch( response_obj.response ) {

					case '-1':

							helper.error();

						break;

					case '0':

							Lungo.Router.article( 'authentication-reset', 'authentication-reset-two' );

							Lungo.Notification.success( 'Verification email sent', '', 'ok', 2, function() {

								Lungo.Notification.hide();

							} );

						break;

					case '1':

							Lungo.Notification.confirm( {

								icon: 'question-sign',

								title: 'We could not find an account with that email address',

								description: 'Would you like to create an account?',

								accept: {

									label: 'Yes',

									callback: function() {

										Lungo.Router.article( 'authentication', 'authentication-register' );

									}

								},

								cancel: {

									label: 'Try again',

									callback: function() {

										Lungo.Notification.hide();

									}
								}

							} );

						break;

					default:

							helper.error();

				}

			}, function() {

				helper.error();

			} );

		}

	},

	reset: function() {

		var request = helper.validate_form( $( auth.elements.reset.two.form ) );

		if ( request != false ) {

			Lungo.Notification.show();

			request['encrypted'] = false;

			request['local_datetime'] = helper.get_date_format();

			var env = Lungo.Core.environment();

			request['device'] = env['os'] == null ? 'Desktop' : env['os'].name;

			helper.ajax( variables.request_reset, request, function( response_json ) {

				var response_obj = $.parseJSON( atob( response_json ) );

				switch( response_obj.response ) {

					case '-1':

							helper.error();

						break;

					case '0':

							sync.save( response_obj );

							Lungo.Router.section( 'home' );

							Lungo.Notification.success( 'Password reset', '', 'ok', 2, function() {

								Lungo.Notification.hide();

							} );

						break;

					case '1':

							Lungo.Notification.error( 'Incorrect email or code', 'Please try again', 'warning-sign' );

						break;

					default:

							helper.error();

				}

			}, function() {

				helper.error();

			} );

		}

	}

};